@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8; tab-width: 8 -*-
  *
- * Copyright (C) 2004-2005 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2004-2006 William Jon McCann <mccann@jhu.edu>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -63,9 +63,9 @@ main (int    argc,
         bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 # ifdef HAVE_BIND_TEXTDOMAIN_CODESET
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-# endif 
+# endif
         textdomain (GETTEXT_PACKAGE);
-#endif 
+#endif
 
         if (! gtk_init_with_args (&argc, &argv, NULL, entries, NULL, &error)) {
                 if (error) {
@@ -82,13 +82,15 @@ main (int    argc,
                 exit (1);
         }
 
-        gs_debug_init (debug);
+        /* debug to a file if in deamon mode */
+        gs_debug_init (debug, ! no_daemon);
         gs_debug ("initializing gnome-screensaver %s", VERSION);
 
         monitor = gs_monitor_new ();
 
-        if (! monitor)
+        if (monitor == NULL) {
                 exit (1);
+        }
 
         error = NULL;
         if (! gs_monitor_start (monitor, &error)) {
@@ -102,8 +104,9 @@ main (int    argc,
         }
 
         /* Don't close stdout and stderr for now */
-        if (! no_daemon && daemon (0, 1))
+        if (! no_daemon && daemon (0, 1)) {
                 g_error ("Could not daemonize: %s", g_strerror (errno));
+        }
 
         gtk_main ();
 
@@ -111,5 +114,7 @@ main (int    argc,
 
         gs_debug ("gnome-screensaver finished");
 
+        gs_debug_shutdown ();
+
 	return 0;
 }
